#
# spec file for package docker-bench-security
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           docker-bench-security
Version:        1.6.1
Release:        1.1
Summary:        Docker Bench for Security
License:        Apache-2.0
Group:          Productivity/Networking/Security
URL:            https://dockerbench.com
Source:         https://github.com/docker/docker-bench-security/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# FIX-UPSTREAM: Adjust the script so that we can package the helper scripts in
#               /usr/libexec. <https://github.com/docker/docker-bench-security/pull/559>
Patch1:         0001-dist-adjust-script-imports-to-be-able-to-use-usr-lib.patch
Requires:       audit
Requires:       coreutils
Requires:       docker >= 1.13.0
Requires:       findutils
Requires:       gawk
Requires:       grep
Requires:       net-tools
Requires:       sed
%if 0%{?suse_version} > 1320
Requires:       net-tools-deprecated
%endif
%if %{?suse_version} > 1110
BuildArch:      noarch
%endif

%description
The Docker Bench for Security is a script that checks for dozens of common
best-practices around deploying Docker containers in production.

The tests are all automated, and implement the CIS Docker Benchmark.

%prep
%autosetup -p1

%build
# Replace LIBEXEC= added by patch1 with the actual libexec directory.
sed -i 's|^LIBEXEC=.*$|LIBEXEC="%{_libexecdir}/%{name}"|' docker-bench-security.sh
chmod +x docker-bench-security.sh

%install
install -D %{name}.sh %{buildroot}/%{_bindir}/docker-bench-security
mkdir -p %{buildroot}/%{_libexecdir}/%{name}
cp -vpr functions/ tests/ %{buildroot}%{_libexecdir}/%{name}

%files
%license LICENSE.md
%doc README.md
%attr(0755,root,root) %{_bindir}/%{name}
%attr(0755,root,root) %{_libexecdir}/%{name}

%changelog
* Fri Oct 18 2024 Aleksa Sarai <asarai@suse.com>
- Update to docker-bench-security v1.6.1. See upstream changelog online at
  <https://github.com/docker/docker-bench-security/releases/tag/v1.6.1>.
  * Align with CIS Docker Benchmark v1.6.0.
  v1.6.0 <https://github.com/docker/docker-bench-security/releases/tag/v1.6.0>
  * Fix image sprawl miscalculation.
  * Add an option to filter out labels to exclude from checks.
  v1.5.0 <https://github.com/docker/docker-bench-security/releases/tag/v1.5.0>
  * Align with CIS Docker Benchmark v1.5.0.
  * Add support for .NanoCpus.
  v1.3.6 <https://github.com/docker/docker-bench-security/releases/tag/v1.3.6>
  * Add CIS Level 1 only functions.
  * Support user namespaces in partition check.
  * Deprecate rule 2.16 for Docker > 19.03.
  * Add checks for capabilities that allows container escape.
  * Implement listing of open ports.
  * Add 4.12 check.
- Rather than patching the script entirely using sed (which can make updates
  error-prone), apply an actual patch to switch to using a LIBEXEC variable we
  can replace during packaging. Backport of
  <https://github.com/docker/docker-bench-security/pull/559>.
  + 0001-dist-adjust-script-imports-to-be-able-to-use-usr-lib.patch
* Thu May  7 2020 Andreas Stieger <andreas.stieger@gmx.de>
- fix include patch of functions_lib.sh (boo#1164631)
* Mon Nov 18 2019 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.3.5:
  * Align with CIS Docker Benchmark v1.2.0
  * Add some command line options to support specific use cases
* Thu Jan 11 2018 kbabioch@suse.com
- update to 1.3.3:
  * Adapt to CIS Docker Community Edition Benchmark v1.1.0
  * Correct check names
  * Require Docker version 1.13.0 or later
  * Handle busybox date conversion
  * Add Docker Swarm configuration checks
* Fri May  5 2017 astieger@suse.com
- update to 1.3.2:
  * improve get_docker_configuration_file_args()
  * add [NOTE] for informational checks with no actual tests
  * fix various tests when using daemon.json
  * use stat instead of ls -ld output
- includes changes from 1.3.1:
  * Add daemon.json support
  * Correct multiple tests
  * Update default alpine Dockerfile
  * Use grep if auditctl isn't present
* Fri Feb 24 2017 astieger@suse.com
- update to 1.3.0:
  * Inspired by the CIS Docker 1.13 Benchmark
  * adjust run-time package requirements
* Mon Aug  1 2016 astieger@suse.com
- Docker Bench for Security v1.1.0:
  * check for docker 1.12.0
  * fix early-docker use
  * mention adjusting volumes
* Tue Jun  7 2016 astieger@suse.com
- checks for docker 1.11.2, no benchmark changes
- requires docker >= 1.10.0
* Wed May 11 2016 astieger@suse.com
- checks for docker 1.11.1
* Mon Apr 18 2016 astieger@suse.com
- checks implementing CIS Docker 1.11.0 Benchmark
  https://benchmarks.cisecurity.org/downloads/show-single/index.cfm?file=docker16.110
- checks for docker 1.11.0
- use stat to verify permissions
- fixes for process detection
* Wed Feb 17 2016 astieger@suse.com
- checks for docker 1.10.1
* Sun Feb  7 2016 astieger@suse.com
- checks for docker 1.10
- improve version check
- fix checks for remotely obtained users/groups
* Fri Nov 27 2015 astieger@suse.com
- checks for docker 1.9.1
- Fix command line option parsing
- check for TCP socket before checking for TLS
* Thu Nov 12 2015 astieger@suse.com
- fix detection of socket security
* Wed Nov  4 2015 astieger@suse.com
- checks for docker 1.9.0
- openSUSE dockerfile added
* Wed Nov  4 2015 astieger@suse.com
- initial package
